ContinuousDomain
================

.. currentmodule:: pqp.data

.. autoclass:: ContinuousDomain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ContinuousDomain.get_cardinality

   .. rubric:: Methods Documentation

   .. automethod:: get_cardinality
